@@ -21,8 +21,6 @@
 
 #include "global.h"
 
-#if GTK_CHECK_VERSION(2,4,0)
-
 #define RG_TARGET_NAMESPACE cSeparatorToolItem
 
 static VALUE
@@ -32,13 +30,9 @@ rg_initialize(VALUE self)
     return Qnil;
 }
 
-#endif
-
 void 
 Init_gtk_separatortoolitem(VALUE mGtk)
 {
-#if GTK_CHECK_VERSION(2,4,0)
     VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(GTK_TYPE_SEPARATOR_TOOL_ITEM, "SeparatorToolItem", mGtk);
     RG_DEF_METHOD(initialize, 0);
-#endif
 }
